==> buildbot_3.3.0.orig.tar.gz: buildbot-3.3.0/master/buildbot/test/unit/util/test_state.py <==
# This file is part of Buildbot.  Buildbot is free software: you can
# redistribute it and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation, version 2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 51
# Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Copyright Buildbot Team Members

from twisted.internet import defer
from twisted.trial import unittest

from buildbot.test.fake import fakemaster
from buildbot.test.util.misc import TestReactorMixin
from buildbot.util import state


class FakeObject(state.StateMixin):
    name = "fake-name"

    def __init__(self, master):
        self.master = master


class TestStateMixin(TestReactorMixin, unittest.TestCase):

    OBJECTID = 19

    def setUp(self):
        self.setUpTestReactor()
        self.master = fakemaster.make_master(self, wantDb=True)
        self.object = FakeObject(self.master)

    @defer.inlineCallbacks
    def test_getState(self):
        self.master.db.state.set_fake_state(self.object, fav_color=['red', 'purple'])
        res = yield self.object.getState('fav_color')

        self.assertEqual(res, ['red', 'purple'])

    @defer.inlineCallbacks
    def test_getState_default(self):
        res = yield self.object.getState('fav_color', 'black')

        self.assertEqual(res, 'black')

    def test_getState_KeyError(self):
        self.master.db.state.set_fake_state(self.object, fav_color=['red', 'purple'])
        d = self.object.getState('fav_book')

        def cb(_):
            self.fail("should not succeed")

        def check_exc(f):
            f.trap(KeyError)

        d.addCallbacks(cb, check_exc)
        return d

    @defer.inlineCallbacks
    def test_setState(self):
        yield self.object.setState('y', 14)

        self.master.db.state.assertStateByClass('fake-name', 'FakeObject',
                                                y=14)

    @defer.inlineCallbacks
    def test_setState_existing(self):
        self.master.db.state.set_fake_state(self.object, x=13)
        yield self.object.setState('x', 14)

        self.master.db.state.assertStateByClass('fake-name', 'FakeObject',
                                                x=14)

==> buildbot_3.7.0.orig.tar.gz: buildbot-3.7.0/master/buildbot/test/unit/util/test_state.py <==
# This file is part of Buildbot.  Buildbot is free software: you can
# redistribute it and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation, version 2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 51
# Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Copyright Buildbot Team Members

from twisted.internet import defer
from twisted.trial import unittest

from buildbot.test.fake import fakemaster
from buildbot.test.reactor import TestReactorMixin
from buildbot.util import state


class FakeObject(state.StateMixin):
    name = "fake-name"

    def __init__(self, master):
        self.master = master


class TestStateMixin(TestReactorMixin, unittest.TestCase):

    OBJECTID = 19

    def setUp(self):
        self.setup_test_reactor()
        self.master = fakemaster.make_master(self, wantDb=True)
        self.object = FakeObject(self.master)

    @defer.inlineCallbacks
    def test_getState(self):
        self.master.db.state.set_fake_state(self.object, fav_color=['red', 'purple'])
        res = yield self.object.getState('fav_color')

        self.assertEqual(res, ['red', 'purple'])

    @defer.inlineCallbacks
    def test_getState_default(self):
        res = yield self.object.getState('fav_color', 'black')

        self.assertEqual(res, 'black')

    def test_getState_KeyError(self):
        self.master.db.state.set_fake_state(self.object, fav_color=['red', 'purple'])
        d = self.object.getState('fav_book')

        def cb(_):
            self.fail("should not succeed")

        def check_exc(f):
            f.trap(KeyError)

        d.addCallbacks(cb, check_exc)
        return d

    @defer.inlineCallbacks
    def test_setState(self):
        yield self.object.setState('y', 14)

        self.master.db.state.assertStateByClass('fake-name', 'FakeObject',
                                                y=14)

    @defer.inlineCallbacks
    def test_setState_existing(self):
        self.master.db.state.set_fake_state(self.object, x=13)
        yield self.object.setState('x', 14)

        self.master.db.state.assertStateByClass('fake-name', 'FakeObject',
                                                x=14)
